@@ -6,8 +6,9 @@
    potential method. It is now able to simulate applied
    magnetic fields along with self consistent Faraday equation.
 
-   Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009 Jean Michel Sellier
+   Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Jean Michel Sellier
    <jeanmichel.sellier@gmail.com>
+   <jsellier@purdue.edu>
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -26,9 +27,9 @@
 
 // =================================================================
 // File Name : archimedes.c
-// Version   : release 0.9.1
+// Version   : release 1.0.0
 // Date of Creation : 07 Dec.2003, Paris, France, Jean Michel Sellier
-// Last Revision : 12 Dec 2009, Cassibile (SR), Italy, Jean Michel Sellier.
+// Last Revision : 14 Aug 2011, Carry le Rouet, France, Jean Michel Sellier.
 // System of Measure : M.K.S.C. System
 // =================================================================
 
@@ -70,7 +71,7 @@
 // definition of the material reference table
 #define NOAMTIA 16   // Number Of All Material Taken Into Account (excluding SiO2)
 // ********************
-#define iSIO2 -1      // reference number to Silicon Oxide
+#define iSIO2 -1     // reference number to Silicon Oxide
 #define SILICON 0    // reference number to Silicon
 #define GAAS 1       // reference number to GaAs
 #define GERMANIUM 2  // reference number to Germanium
@@ -250,7 +251,7 @@ Usage: %s [OPTION] file...\n",progname);
          your translation!
          no-wrap */
       printf ("\
-Report bugs to jeanmichel.sellier@gmail.com\n");
+Report bugs to jeanmichel.sellier@gmail.com or jsellier@purdue.edu\n");
 
       exit (0);
     }
@@ -258,7 +259,7 @@ Report bugs to jeanmichel.sellier@gmail.com\n");
   if (v)
     {
       /* Print version number.  */
-      printf("archimedes - GNU archimedes 0.8.0\n");
+      printf("archimedes - GNU archimedes 1.0.0\n");
       /* xgettext: no-wrap */
       printf("\n");
       printf("\
@@ -268,7 +269,7 @@ PARTICULAR PURPOSE.\n\
 You may redistribute copies of GNU %s under the terms\n\
 of the GNU General Public License.\n\
 For more information about these matters, see the file named COPYING.\n",
-              "2004, 2005, 2006, 2007, 2008","Archimedes");
+              "2004 - 2011","Archimedes");
       exit (0);
     }
   else if (z){
@@ -285,49 +286,53 @@ For more information about these matters, see the file named COPYING.\n",
 // Material constants here!
 // ========================
 // Silicon electrons in the X-valley
-// Germanium electrons in the X-valley
-// All the other semiconductor compounds have electrons in the Gamma- and L-valley
-// definition of the number of valley for every material
-     NOVALLEY[SILICON]=1;
-     NOVALLEY[GERMANIUM]=1;
-     NOVALLEY[GAAS]=2;
-     NOVALLEY[INSB]=2;
-     NOVALLEY[ALSB]=2;
-     NOVALLEY[ALXINXSB]=2;
-     NOVALLEY[ALXIN1XSB]=2;
-     NOVALLEY[ALAS]=2;
-     NOVALLEY[ALP]=2;
-     NOVALLEY[GAP]=2;
-     NOVALLEY[GASB]=2;
-     NOVALLEY[INAS]=2;
-     NOVALLEY[INP]=2;
-     NOVALLEY[INXGA1XAS]=2;
-     NOVALLEY[INXAL1XAS]=2;
-     NOVALLEY[INXGAXXAS]=2;
+// Germanium electrons in the Gamma-valley
+// GaAs electrons in the Gamma- and L-valley
+// For the others, see comments below
+     NOVALLEY[SILICON]=1;    // X-valley
+     NOVALLEY[GERMANIUM]=1;  // G-valley
+     NOVALLEY[GAAS]=2;       // G and L-valleys
+     NOVALLEY[INSB]=1;       // G valley
+     NOVALLEY[ALSB]=1;       // G-valley
+     NOVALLEY[ALXINXSB]=1;   // G-valley
+     NOVALLEY[ALXIN1XSB]=1;  // G-valley
+     NOVALLEY[ALAS]=1;       // G-valley
+     NOVALLEY[ALP]=1;        // G-valley
+     NOVALLEY[GAP]=1;        // G-valley
+     NOVALLEY[GASB]=1;       // G-valley
+     NOVALLEY[INAS]=1;       // G-valley
+     NOVALLEY[INP]=1;        // G-valley
+     NOVALLEY[INXGA1XAS]=1;  // only G-valley
+     NOVALLEY[INXAL1XAS]=1;  // G-valley
+     NOVALLEY[INXGAXXAS]=1;  // only G-valley
 // Dielectric constant for Silicon Oxide SiO2
-     EPSRSIO2=17.0*EPS0;
+     EPSRSIO2=3.9*EPS0;         // see http://en.wikipedia.org/wiki/Relative_permittivity
 // Dielectric constant for Semiconducting materials
-     EPSR[SILICON]=11.7*EPS0;
-     EPSR[GERMANIUM]=16.2*EPS0;
-     EPSR[GAAS]=12.90*EPS0;
-     EPSR[INSB]=17.65*EPS0;
-     EPSR[ALSB]=12.04*EPS0;
-     EPSR[ALAS]=10.06;
-     EPSR[ALP]=9.80;
-     EPSR[GAP]=11.10;
-     EPSR[GASB]=15.69;
-     EPSR[INAS]=15.15;
-     EPSR[INP]=12.61;
+// STATIC
+// ======
+     EPSR[SILICON]=11.68;       // see http://en.wikipedia.org/wiki/Relative_permittivity
+     EPSR[GERMANIUM]=16.2;      // see http://www.ioffe.ru/SVA/NSM/Semicond/Ge/basic.html
+     EPSR[GAAS]=12.90;          // see http://www.ioffe.ru/SVA/NSM/Semicond/GaAs/basic.html
+     EPSR[INSB]=16.8;           // see http://www.ioffe.ru/SVA/NSM/Semicond/InSb/basic.html
+     EPSR[ALSB]=12.04;          // Fischetti conversations
+     EPSR[ALAS]=12.90-2.84;     // see http://www.ioffe.ru/SVA/NSM/Semicond/AlGaAs/basic.html (x=1.0)
+     EPSR[ALP]=9.80;            // Fischetti conversations
+     EPSR[GAP]=11.10;           // see http://www.ioffe.ru/SVA/NSM/Semicond/GaP/basic.html
+     EPSR[GASB]=15.69;          // see http://www.ioffe.ru/SVA/NSM/Semicond/GaSb/basic.html
+     EPSR[INAS]=15.15;          // see http://www.ioffe.ru/SVA/NSM/Semicond/InAs/basic.html
+     EPSR[INP]=12.50;           // see http://www.ioffe.ru/SVA/NSM/Semicond/InP/basic.html 
 // III-V semiconductor compounds high frequency dieletric constant
-     EPF[GAAS]=10.92;
-     EPF[INSB]=15.68;
-     EPF[ALSB]=9.88;
-     EPF[ALAS]=8.16;
-     EPF[ALP]=7.54;
-     EPF[GAP]=9.08;
-     EPF[GASB]=14.44;
-     EPF[INAS]=12.75;
-     EPF[INP]=9.61;
+// HIGH FREQUENCY
+// ==============
+     EPF[GAAS]=10.89;           // see http://www.ioffe.ru/SVA/NSM/Semicond/GaAs/basic.html
+     EPF[INSB]=15.68;           // Fischetti conversations
+     EPF[ALSB]=9.88;            // Fiscehtti conversations
+     EPF[ALAS]=10.89-2.73;      // see http://www.ioffe.ru/SVA/NSM/Semicond/AlGaAs/basic.html (x=1.0)
+     EPF[ALP]=7.54;             // Fischetti conversations
+     EPF[GAP]=9.11;             // see http://www.ioffe.ru/SVA/NSM/Semicond/GaP/basic.html
+     EPF[GASB]=14.44;           // see http://www.ioffe.ru/SVA/NSM/Semicond/GaSb/basic.html
+     EPF[INAS]=12.3;            // see http://www.ioffe.ru/SVA/NSM/Semicond/InAs/basic.html
+     EPF[INP]=9.61;             // see http://www.ioffe.ru/SVA/NSM/Semicond/InP/basic.html
      int ii;
      for(ii=0;ii<NOAMTIA;ii++){
        int i;
@@ -337,111 +342,103 @@ For more information about these matters, see the file named COPYING.\n",
          ZF[ii][i]=0.;
        }
      }
-// Silicon optical phonon scattering energy (eV)
-     HWO[SILICON][0]=0.0120;
-     HWO[SILICON][1]=0.0185;
-     HWO[SILICON][2]=0.0190;
-     HWO[SILICON][3]=0.0474;
-     HWO[SILICON][4]=0.0612;
-     HWO[SILICON][5]=0.0590;
-// Germanium optical phonon scattering energy (eV)
-     HWO[GERMANIUM][0]=0.09;
-// III-V semiconductor compounds optical phonon scattering energy (eV)
-     HWO[GAAS][0]=0.03536;
-     HWO[INSB][0]=0.0282;
-     HWO[ALSB][0]=0.0360;
-     HWO[ALAS][0]=0.05009;
-     HWO[ALP][0]=0.06212;
-     HWO[GAP][0]=0.04523;
-     HWO[GASB][0]=0.02529;
-     HWO[INAS][0]=0.03008;
-     HWO[INP][0]=0.04240;
-// Silicon optical coupling constants (eV/m)
-     DTK[SILICON][0]=0.05e11;
-     DTK[SILICON][1]=0.08e11;
-     DTK[SILICON][2]=0.03e11;
-     DTK[SILICON][3]=0.20e11;
-     DTK[SILICON][4]=1.14e11;
-     DTK[SILICON][5]=0.20e11;
-// Germanium optical coupling constants (eV/m)
-     DTK[GERMANIUM][0]=1.889e11;
-// III-V semiconductor compounds optical coupling constant (eV/m)
-     DTK[GAAS][0]=1.11e11;
-     DTK[INSB][0]=0.47e11;
-     DTK[ALSB][0]=0.55e11;
-     DTK[ALAS][0]=3.0e11;
-     DTK[ALP][0]=0.95e11;
-     DTK[GAP][0]=5.33e11;
-     DTK[GASB][0]=0.94e11;
-     DTK[INAS][0]=3.59e11;
-     DTK[INP][0]=2.46e11;
-// Silicon optical phonon Z-factor
-     ZF[SILICON][0]=1.;
-     ZF[SILICON][1]=1.;
-     ZF[SILICON][2]=4.;
-     ZF[SILICON][3]=4.;
-     ZF[SILICON][4]=1.;
-     ZF[SILICON][5]=4.;
-// Germanium optical phonon Z-factor
-     ZF[GERMANIUM][0]=1.;
-// III-V semiconductor compounds optical phonon Z-factor
-     ZF[GAAS][0]=1.;
-     ZF[INSB][0]=1.;
-     ZF[ALSB][0]=1.;
-     ZF[ALAS][0]=1.;
-     ZF[ALP][0]=1.;
-     ZF[GAP][0]=1.;
-     ZF[GASB][0]=1.;
-     ZF[INAS][0]=1.;
-     ZF[INP][0]=1.;
-// Silicon Crystal Density (Kg/m^3)
-     RHO[SILICON]=2330.;
-// Germanium Crystal Density (Kg/m^3)
-     RHO[GERMANIUM]=5320.;
-// III-V semiconductor compounds Crystal Density (Kg/m^3)
-     RHO[GAAS]=5360.;
-     RHO[INSB]=5790.;
-     RHO[ALSB]=4288.;
-     RHO[ALAS]=5650.;
-     RHO[ALP]=7410.;
-     RHO[GAP]=5850.;
-     RHO[GASB]=3970.;
-     RHO[INAS]=4280.;
-     RHO[INP]=5130.;
-// Silicon acoustic deformation potential (Joule)
-     DA[SILICON]=9.*1.60217733e-19;
-// Germanium acoustic deformation potential (Joule)
-     DA[GERMANIUM]=9.*1.60217733e-19;
-// III-V semiconductor compounds acoustic deformation potential (Joule)
-     DA[GAAS]=7.*1.60217733e-19;
-     DA[INSB]=5.96*1.60217733e-19;
-     DA[ALSB]=4.6*1.60217733e-19;
-     DA[ALAS]=9.3*1.60217733e-19;
-     DA[ALP]=9.3*1.60217733e-19;
-     DA[GAP]=7.4*1.60217733e-19;
-     DA[GASB]=9.*1.60217733e-19;
-     DA[INAS]=8.2*1.60217733e-19;
-     DA[INP]=6.2*1.60217733e-19;
-// Silicon longitudinal sound velocity (m/sec)
-     UL[SILICON]=9040.;
-// Germanium longitudinal sound velocity (m/sec)
-     UL[GERMANIUM]=5400.;
-// III-V semiconductor compounds longitudinal sound velocity (m/sec)
-     UL[GAAS]=5240.;
-     UL[INSB]=4060.;
-     UL[ALSB]=4600.;
-     UL[ALAS]=5650.;
-     UL[ALP]=7410.;
-     UL[GAP]=5850.;
-     UL[GASB]=3970.;
-     UL[INAS]=4280.;
-     UL[INP]=5130.;
-// Silicon minimum energy
-     EMIN[SILICON][1]=0.0;
-// Germanium minimum energy
-     EMIN[GERMANIUM][1]=0.173;
-// III-V semiconductor compounds minimum energy of GAMMA-valley
-     EMIN[GAAS][1]=0.0;
+// Optical phonon scattering energy (eV)
+     HWO[SILICON][0]=0.0120;    // Sellier, Tomizawa
+     HWO[SILICON][1]=0.0185;    // Sellier, Tomizawa
+     HWO[SILICON][2]=0.0190;    // Sellier, Tomizawa
+     HWO[SILICON][3]=0.0474;    // Sellier, Tomizawa
+     HWO[SILICON][4]=0.0612;    // Sellier, Tomizawa
+     HWO[SILICON][5]=0.0590;    // Sellier, Tomizawa
+     HWO[GERMANIUM][0]=0.03704; // Fischetti
+     HWO[GAAS][0]=0.03536;      // Fischetti
+     HWO[INSB][0]=0.02404;      // Fischetti
+     HWO[ALSB][0]=0.0360;       // Fischetti
+     HWO[ALAS][0]=0.05009;      // Fischetti
+     HWO[ALP][0]=0.06211;       // Fischetti
+     HWO[GAP][0]=0.04523;       // Fischetti
+     HWO[GASB][0]=0.02529;      // Fischetti
+     HWO[INAS][0]=0.03008;      // Fischetti
+     HWO[INP][0]=0.04240;       // Fischetti
+// Optical coupling constants (eV/m)
+     DTK[SILICON][0]=0.05e11;     // Jacoboni Reggiani
+     DTK[SILICON][1]=0.08e11;     // Jacoboni Reggiani
+     DTK[SILICON][2]=0.03e11;     // Jacoboni Reggiani
+     DTK[SILICON][3]=0.20e11;     // Jacoboni Reggiani
+     DTK[SILICON][4]=1.14e11;     // Jacoboni Reggiani
+     DTK[SILICON][5]=0.20e11;     // Jacoboni Reggiani
+     DTK[GERMANIUM][0]=0.0;       // Jacoboni Reggiani
+     DTK[GERMANIUM][1]=0.079e11;  // Jacoboni Reggiani
+     DTK[GERMANIUM][2]=0.0;       // Jacoboni Reggiani
+     DTK[GERMANIUM][3]=0.0;       // Jacoboni Reggiani
+     DTK[GERMANIUM][4]=0.95e11;   // Jacoboni Reggiani
+     DTK[GERMANIUM][5]=0.0;       // Jacoboni Reggiani
+     DTK[GAAS][0]=1.11e11;        // Sellier, Tomizawa
+     DTK[INSB][0]=0.47e11; // see ???
+     DTK[ALSB][0]=0.55e11; // see ???
+     DTK[ALAS][0]=3.0e11;  // see ???
+     DTK[ALP][0]=0.95e11;  // see ???
+     DTK[GAP][0]=5.33e11;  // see ???
+     DTK[GASB][0]=0.94e11; // see ???
+     DTK[INAS][0]=3.59e11; // see ???
+     DTK[INP][0]=2.46e11;  // see ???
+// Optical phonon Z-factor
+     ZF[SILICON][0]=1.;   // Sellier
+     ZF[SILICON][1]=1.;   // Sellier
+     ZF[SILICON][2]=4.;   // Sellier
+     ZF[SILICON][3]=4.;   // Sellier
+     ZF[SILICON][4]=1.;   // Sellier
+     ZF[SILICON][5]=4.;   // Sellier
+     ZF[GERMANIUM][0]=1.; // see ???
+     ZF[GAAS][0]=1.;      // Sellier
+     ZF[INSB][0]=1.;      // see ???
+     ZF[ALSB][0]=1.;      // see ???
+     ZF[ALAS][0]=1.;      // see ???
+     ZF[ALP][0]=1.;       // see ???
+     ZF[GAP][0]=1.;       // see ???
+     ZF[GASB][0]=1.;      // see ???
+     ZF[INAS][0]=1.;      // see ???
+     ZF[INP][0]=1.;       // see ???
+// Crystal Density (Kg/m^3)
+     RHO[SILICON]=2.33e3;   // Fischetti conversations
+     RHO[GERMANIUM]=5.32e3; // Fischetti conversations
+     RHO[GAAS]=5.36e3;      // Fischetti conversations
+     RHO[INSB]=5.78e3;      // Fischetti conversations
+     RHO[ALSB]=4.26e3;      // Fischetti conversations
+     RHO[ALAS]=3.76e3;      // Fischetti conversations
+     RHO[ALP]=2.40e3;       // Fischetti conversations
+     RHO[GAP]=4.14e3;       // Fischetti conversations
+     RHO[GASB]=5.61e3;      // Fischetti conversations
+     RHO[INAS]=5.67e3;      // Fischetti conversations
+     RHO[INP]=4.81e3;       // Fischetti conversations
+// Acoustic deformation potential (Joule)
+     DA[SILICON]=9.*Q;      // Fischetti -- Jacoboni Reggiani
+     DA[GERMANIUM]=9.*Q;    // Fischetti -- Jacoboni Reggiani
+     DA[GAAS]=7.*Q;         // Fischetti - Gamma valley
+     DA[INSB]=7.*Q;         // Fischetti
+     DA[ALSB]=4.6*Q;        // Fischetti
+     DA[ALAS]=9.3*Q;        // Fischetti
+     DA[ALP]=9.3*Q;         // Fischetti
+     DA[GAP]=7.4*Q;         // Fischetti
+     DA[GASB]=9.*Q;         // Fischetti
+     DA[INAS]=8.2*Q;        // Fischetti
+     DA[INP]=6.2*Q;         // Fischetti
+// Longitudinal sound velocity (m/sec)
+     UL[SILICON]=9.18e3;   // Fischetti
+     UL[GERMANIUM]=5.4e3;  // Fischetti
+     UL[GAAS]=5.24e3;      // Fischetti
+     UL[INSB]=3.41e3;      // Fischetti
+     UL[ALSB]=4.25e3;      // Fischetti
+     UL[ALAS]=5.65e3;      // Fischetti
+     UL[ALP]=7.41e3;       // Fischetti
+     UL[GAP]=5.85e3;       // Fischetti
+     UL[GASB]=3.97e3;      // Fischetti
+     UL[INAS]=4.28e3;      // Fischetti
+     UL[INP]=5.13e3;       // Fischetti
+// Band minimum energy
+// first valley
+     EMIN[SILICON][1]=0.0;     // Sellier, Fischetti, etc.
+     EMIN[GERMANIUM][1]=0.173; 
+     EMIN[GAAS][1]=0.0;        // Tomizawa
      EMIN[INSB][1]=0.0;
      EMIN[ALSB][1]=0.507;
      EMIN[ALAS][1]=0.767;
@@ -450,41 +447,25 @@ For more information about these matters, see the file named COPYING.\n",
      EMIN[GASB][1]=0.0;
      EMIN[INAS][1]=0.0;
      EMIN[INP][1]=0.0;
-// III-V semiconductor compounds minimum energy of L-valley (eV)
+// eventual second valley
      EMIN[GAAS][2]=0.323;
-     EMIN[INSB][2]=1.038;
-     EMIN[ALSB][2]=0.292;
-     EMIN[ALAS][2]=0.332;
-     EMIN[ALP][2]=0.824;
-     EMIN[GAP][2]=0.415;
-     EMIN[GASB][2]=0.217;
-     EMIN[INAS][2]=1.078;
-     EMIN[INP][2]=0.832;
+
 // Definition of effective mass for all materials in all valleys
-     MSTAR[SILICON][1]=0.32;
-     MSTAR[GAAS][1]=0.067; // Gamma-valley
-     MSTAR[GAAS][2]=0.350; // L-valley
-     MSTAR[GERMANIUM][1]=0.22;
-     MSTAR[INSB][1]=0.013;
-     MSTAR[INSB][2]=0.442;
-     MSTAR[ALSB][1]=0.14;
-     MSTAR[ALSB][2]=0.442;
-     MSTAR[ALAS][1]=0.149;
-     MSTAR[ALAS][2]=pow(1.456*pow(0.165,2.),1./3.);
-     MSTAR[ALP][1]=0.166;
-     MSTAR[ALP][2]=pow(1.556*pow(0.162,2.),1./3.);
-     MSTAR[GAP][1]=0.122;
-     MSTAR[GAP][2]=pow(1.498*pow(0.358,2.),1./3.);
-     MSTAR[GASB][1]=0.048;
-     MSTAR[GASB][2]=pow(1.4*pow(0.139,2.),1./3.);
-     MSTAR[INAS][1]=0.031;
-     MSTAR[INAS][2]=pow(1.590*pow(0.326,2.),1./3.);
-     MSTAR[INP][1]=0.083;
-     MSTAR[INP][2]=pow(1.893*pow(0.425,2.),1./3.);
-// non-parabolicity coefficient for Silicon
-     alphaK[SILICON][1]=0.5;
-// non-parabolicity coefficient for Germanium
-     alphaK[GERMANIUM][1]=0.65;
+     MSTAR[SILICON][1]=0.32;     // see Sellier, Tomizawa, etc.
+     MSTAR[GAAS][1]=0.067;       // Gamma-valley -- see Tomizawa
+     MSTAR[GAAS][2]=0.350;       // L-valley     -- see Tomizawa
+     MSTAR[GERMANIUM][1]=0.12;   // Gamma valley -- see http://ecee.colorado.edu/~bart/book/effmass.htm#long
+     MSTAR[INSB][1]=0.0135;      // Gamma-valley -- see Ram-Mohan
+     MSTAR[ALSB][1]=0.14;        // Gamma-valley -- See Ram-Mohan
+     MSTAR[ALAS][1]=0.149;       // Gamma-valley -- see Ram-Mohan J.App.Phys. Vol.89, Num.11
+     MSTAR[ALP][1]=0.22;         // Gamma-valley -- see Ram-Mohan
+     MSTAR[GAP][1]=0.13;         // Gamma-valley -- see Ram-Mohan J.App.Phys. Vol.89, Num.11
+     MSTAR[GASB][1]=0.039;       // Gamma-valley -- see Ram-Mohan
+     MSTAR[INAS][1]=0.026;       // Gamma-valley -- see Ram-Mohan J.App.Phys. Vol.89, Num.11
+     MSTAR[INP][1]=0.0795;       // Gamma-valley -- see Ram-Mohan
+// non-parabolicity coefficients
+     alphaK[SILICON][1]=0.5;    // see Sellier, Tomizawa
+     alphaK[GERMANIUM][1]=0.3;  // Gamma valley - Jacoboni Reggiani
 // ======================================================
 // ======================================================
 
