@@ -1,4 +1,4 @@
-/* mcparameters.h -- This file is part of Archimedes release 0.1.2.
+/* mcparameters.h -- This file is part of Archimedes release 1.0.0.
    Archimedes is a simulator for Submicron 2D III-V semiconductor
    Devices. It implements the Monte Carlo method
    for the simulation of the semiclassical Boltzmann equation for both
@@ -6,7 +6,7 @@
    of effective potential method. It is now able to simulate applied
    magnetic fields along with self consistent Faraday equation.
 
-   Copyright (C) 2004, 2005, 2006, 2007 Jean Michel Sellier <sellier@dmi.unict.it>
+   Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Jean Michel Sellier <jeanmichel.sellier@gmail.com>
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 
 // ######################################################
 // Created on 05 sep.2004, Siracusa, J.M.Sellier
-// Last modif. : 13 Sep.2007, Siracusa, J.M.Sellier
+// Last modif. : 12 Aug.2011, Carry le Rouet, France, J.M.Sellier
 // ######################################################
 
 // Definition of the variables needed for taking into
@@ -57,7 +57,7 @@ MCparameters(int Material)
 // Effective mass for the GAMMA and L-Valley, respectively
   am1=MSTAR[Material][1]*M;
   am2=MSTAR[Material][2]*M;
-  eps=EPSR[Material];
+  eps=EPSR[Material]*EPS0;
   epf=EPF[Material]*EPS0;
   ep=1./(1./epf-1./eps);
 
